Revisioned Immutable
====================

.. automodule:: shoobx.immutable.revisioned

   .. autoclass:: RevisionedImmutableBase
      :members:
      :special-members:
      :undoc-members:
      :member-order: bysource
      :exclude-members: __dict__, __implemented__, __module__, __provides__,
                        __providedBy__, __weakref__

      See :class:`shoobx.immutable.interfaces.IRevisionedImmutable`

   .. autoclass:: RevisionedImmutable
      :members:
      :special-members:
      :undoc-members:
      :member-order: bysource
      :exclude-members: __dict__, __implemented__, __module__, __provides__,
                        __providedBy__, __weakref__

   .. autoclass:: SimpleRevisionedImmutableManager
      :members:
      :undoc-members:
      :member-order: bysource

      See :class:`shoobx.immutable.interfaces.IRevisionedImmutableManager`

   .. autoclass:: RevisionedMapping
      :members:
      :special-members:
      :undoc-members:
      :member-order: bysource
      :exclude-members: __dict__, __implemented__, __module__, __provides__,
                        __providedBy__, __weakref__

